@@ -28,3 +28,9 @@ def truncate(title: str) -> str:
     if len(title) >= 40:
         title = title[:40] + "…"
     return title
+
+
+# Keep this in sync with bodhi.server.util.MENTION_RE
+# (enhancement: create a bodhi-common package that every subpackage
+# would depend on and put it there)
+MENTION_RE = r'(?<!\S)(@\w+)'
